---
name: db.test.py
description: Test database driver, database must exist and set by db.connect.
keywords: [ database, attribute table ]
---

# db.test.py

Test database driver, database must exist and set by db.connect.

=== "Command line"

    **db.test.py**
    **test**=*string*
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    db.test.py test=string
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***db.test.py***",
        **test**,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("db.test.py", test="string")
    ```

## Parameters

=== "Command line"

    **test**=*string* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Test name  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *test1*  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **test** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Test name  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *test1*  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*db.test* tests database driver and database server running set of SQL
queries. Database must exist and connection must be set by *db.connect*.

## EXAMPLE

Test current SQL backend driver:

```sh
db.connect -p
db.test test=test1
```

## SEE ALSO

*[GRASS SQL interface](sql.md), [db.connect](db.connect.md),
[db.describe](db.describe.md), [db.drivers](db.drivers.md)*

## AUTHOR

Radim Blazek

## SOURCE CODE

Available at: [db.test source code](https://github.com/OSGeo/grass/tree/main/scripts/db.test)
([history](https://github.com/OSGeo/grass/commits/main/scripts/db.test))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
